@@ -1,4 +1,4 @@
-from arkitekt.apps import Arkitekt
+from arkitekt.apps.connected import App
 from arkitekt.apps.rekuest import ArkitektRekuest, ArkitektAgent
 from fakts.grants.remote.device_code import DeviceCodeGrant
 from fakts.fakts import Fakts
@@ -15,6 +15,7 @@ import logging
 from koil.composition import PedanticKoil
 import os
 from .utils import create_arkitekt_folder
+from rekuest.contrib.fakts.websocket_agent_transport import FaktsWebsocketAgentTransport
 
 
 def easy(
@@ -27,8 +28,9 @@ def easy(
     allow_sync_in_async: bool = True,
     log_level: str = "ERROR",
     token: str = None,
+    no_cache: bool = False,
     instance_id: str = "main",
-) -> Arkitekt:
+) -> App:
     """Easy app creation
 
     A simple way to create an Arkitekt app with a device code grant
@@ -50,7 +52,6 @@ def easy(
 
     create_arkitekt_folder(with_cache=True)
 
-
     manifest = Manifest(
         version=version,
         identifier=identifier,
@@ -58,8 +59,6 @@ def easy(
         logo=logo,
     )
 
-
-
     try:
         from rich.logging import RichHandler
 
@@ -67,7 +66,7 @@ def easy(
     except ImportError:
         logging.basicConfig(level=log_level)
 
-    return Arkitekt(
+    return App(
         identifier=identifier,
         version=version,
         koil=PedanticKoil(sync_in_async=allow_sync_in_async),
@@ -75,17 +74,19 @@ def easy(
             grant=CacheGrant(
                 cache_file=f".arkitekt/cache/{identifier}-{version}_cache.json",
                 hash=f"{identifier}-{version}-{url}",
+                skip_cache=no_cache,
                 grant=DeviceCodeGrant(
                     manifest=manifest,
                     open_browser=not headless,
                     discovery=WellKnownDiscovery(
-                                url=url,
-                                auto_protocols=["https", "http"]),
+                        url=url, auto_protocols=["https", "http"]
+                    ),
                 ),
             )
         ),
         herre=Herre(
             grant=HerreCacheGrant(
+                skip_cache=no_cache,
                 cache_file=f".arkitekt/cache/{identifier}-{version}_herre_cache.json",
                 hash=f"{identifier}-{version}-{url}",
                 grant=RefreshGrant(grant=FaktsGrant()),
@@ -102,12 +103,20 @@ def easy(
 def jupy(
     identifier: str,
     version: str = "latest",
-    url: str = "http://localhost:8000/f/",
+    url: str = "http://localhost:8000",
     headless: bool = False,
-) -> Arkitekt:
-
+    instance_id: str = "main",
+    no_cache: bool = False,
+) -> App:
     app = easy(
-        identifier, version, url, headless, allow_sync_in_async=True, log_level="ERROR"
+        identifier,
+        version,
+        url=url,
+        headless=headless,
+        allow_sync_in_async=True,
+        log_level="ERROR",
+        instance_id=instance_id,
+        no_cache=no_cache,
     )
     app.enter()
     return app
@@ -119,7 +128,10 @@ def port(
     url: str = "http://lok:8000",
     log_level: str = "ERROR",
     token: str = None,
-) -> Arkitekt:
+    headless: bool = False,
+    instance_id: str = "main",
+    no_cache: bool = False,
+) -> App:
     """Easy port creation
 
     A simple way to create an Arkitekt app with a device code grant
@@ -155,12 +167,13 @@ def port(
     except ImportError:
         logging.basicConfig(level=log_level)
 
-    return Arkitekt(
+    return App(
         identifier=identifier,
         version=version,
         fakts=Fakts(
             grant=CacheGrant(
                 cache_file=f".arkitekt/cache/{identifier}-{version}_cache.json",
+                skip_cache=no_cache,
                 hash=f"{identifier}-{version}-{url}",
                 grant=StaticGrant(token=token, discovery=WellKnownDiscovery(url=url)),
             )
@@ -169,43 +182,104 @@ def port(
             grant=HerreCacheGrant(
                 cache_file=f".arkitekt/cache/{identifier}-{version}_herre_cache.json",
                 hash=f"{identifier}-{version}-{url}",
+                skip_cache=no_cache,
                 grant=RefreshGrant(grant=FaktsGrant()),
             ),
         ),
+        rekuest=ArkitektRekuest(
+            agent=ArkitektAgent(
+                instance_id=instance_id,
+            )
+        ),
     )
 
 
-def qt(identifier: str, version: str, parent) -> Arkitekt:
-    """
-    A simple way to create an Arkitekt app within a Qt application stilll
-    utilizing a device code grant to authenticate the user on an application
-    level
-    """
+def scheduler(
+    identifier: str,
+    version: str = "latest",
+    logo: str = None,
+    scopes: List[str] = None,
+    url: str = "http://localhost:8000",
+    headless: bool = False,
+    allow_sync_in_async: bool = True,
+    log_level: str = "INFO",
+    token: str = None,
+    instance_id: str = "main",
+    no_cache: bool = False,
+) -> App:
+    """Scheduler app creation
 
-    from koil.composition.qt import QtPedanticKoil
+    A an arkitekt scheduler app with a device code grant and a reaktion agent
+    this app will be able to deploy graphs from fluss
+
+    Args:
+        identifier (str): The apps identifier
+        version (str, optional): The apps verion. Defaults to "latest".
+        url (_type_, optional): The app configuration url. Defaults to "http://localhost:8000/f/".
+        headless (bool, optional): Do not open a browser window. Defaults to False.
+        allow_sync_in_async (bool, optional): Should we allow the creation of a sync interface in an async loop (necessary for a sync interface in jupyter). Defaults to True.
+
+    Returns:
+        Arkitekt: _description_
+    """
+    try:
+        from reaktion.agent import ReaktionAgent
+    except ImportError as e:
+        raise ImportError(
+            "You need to install reaktion to use the scheduler function"
+        ) from e
+
+    url = os.getenv("FAKTS_URL", url)
+    token = os.getenv("FAKTS_TOKEN", token)
 
     create_arkitekt_folder(with_cache=True)
 
-    return Arkitekt(
+    manifest = Manifest(
+        version=version,
+        identifier=identifier,
+        scopes=scopes if scopes else ["openid"],
+        logo=logo,
+    )
+
+    try:
+        from rich.logging import RichHandler
+
+        logging.basicConfig(level=log_level, handlers=[RichHandler()])
+    except ImportError:
+        logging.basicConfig(level=log_level)
+
+    return App(
         identifier=identifier,
         version=version,
-        koil=QtPedanticKoil(parent=parent),
+        koil=PedanticKoil(sync_in_async=allow_sync_in_async),
         fakts=Fakts(
             grant=CacheGrant(
+                skip_cache=no_cache,
                 cache_file=f".arkitekt/cache/{identifier}-{version}_cache.json",
+                hash=f"{identifier}-{version}-{url}",
                 grant=DeviceCodeGrant(
-                    identifier=identifier,
-                    version=version,
+                    manifest=manifest,
+                    open_browser=not headless,
+                    discovery=WellKnownDiscovery(
+                        url=url, auto_protocols=["https", "http"]
+                    ),
                 ),
             )
         ),
         herre=Herre(
             grant=HerreCacheGrant(
                 cache_file=f".arkitekt/cache/{identifier}-{version}_herre_cache.json",
-                hash=f"{identifier}-{version}",
-                grant=FaktsGrant(),
+                hash=f"{identifier}-{version}-{url}",
+                skip_cache=no_cache,
+                grant=RefreshGrant(grant=FaktsGrant()),
             ),
         ),
+        rekuest=ArkitektRekuest(
+            agent=ReaktionAgent(
+                instance_id=instance_id,
+                transport=FaktsWebsocketAgentTransport(fakts_group="rekuest.agent"),
+            )
+        ),
     )
 
 
@@ -213,12 +287,14 @@ def publicqt(
     identifier: str,
     version: str = "latest",
     parent=None,
-    image: Optional[str] = None,
+    logo: Optional[str] = None,
     scopes: Optional[List[str]] = None,
     beacon_widget=None,
     login_widget=None,
-    force_herre_grant = None
-) -> Arkitekt:
+    force_herre_grant=None,
+    instance_id: str = "main",
+    no_cache: bool = False,
+) -> App:
     """Public QtApp creation
 
     A simple way to create an Arkitekt app with a public grant (allowing users to sign
@@ -246,7 +322,7 @@ def publicqt(
         version=version,
         identifier=identifier,
         scopes=scopes or ["openid", "read", "write"],
-        image=image,
+        logo=logo,
     )
 
     create_arkitekt_folder(with_cache=True)
@@ -255,13 +331,13 @@ def publicqt(
 
     login_widget = login_widget or LoginWidget(identifier, version, parent=parent)
     f = FaktsGrant(grant_class=force_herre_grant)
-    print(f)
-    app = Arkitekt(
+    app = App(
         identifier=identifier,
         version=version,
         fakts=Fakts(
             grant=CacheGrant(
                 cache_file=f".arkitekt/cache/{identifier}-{version}_fakts_cache.json",
+                skip_cache=no_cache,
                 grant=RetrieveGrant(
                     manifest=manifest,
                     redirect_uri="http://localhost:6767",
@@ -269,7 +345,6 @@ def publicqt(
                         widget=beacon_widget,
                         allow_appending_slash=True,
                         auto_protocols=["http", "https"],
-
                     ),
                 ),
             ),
@@ -287,49 +362,11 @@ def publicqt(
                 ),
             ),
         ),
+        rekuest=ArkitektRekuest(
+            agent=ArkitektAgent(
+                instance_id=instance_id,
+            )
+        ),
     )
 
     return app
-
-
-def flussi(
-    identifier: str, version: str = "latest", url: str = "http://localhost:8000"
-):
-    """
-    A simple way to create an Arkitekt app with a device code grant
-    it will cache the configuration in a file called `identifier`_token.json
-    and the cache in a file called `identifier`_cache.json
-    """
-
-    from arkitekt.apps.fluss import ConnectedFluss
-
-    create_arkitekt_folder(with_cache=True)
-
-
-    manifest = Manifest(
-        version=version,
-        identifier=identifier,
-    )
-
-
-    return ConnectedFluss(
-        identifier=identifier,
-        version=version,
-        fakts=Fakts(
-            grant=CacheGrant(
-                cache_file=f".arkitekt/cache/{identifier}-{version}_cache.json",
-                hash=f"{identifier}-{version}-{url}",
-                grant=DeviceCodeGrant(
-                    manifest,
-                    discovery=WellKnownDiscovery(url=url),
-                ),
-            )
-        ),
-        herre=Herre(
-            grant=HerreCacheGrant(
-                cache_file=f".arkitekt/cache/{identifier}-{version}_herre_cache.json",
-                hash=f"{identifier}-{version}-{url}",
-                grant=RefreshGrant(grant=FaktsGrant()),
-            ),
-        ),
-    )
