@@ -93,6 +93,47 @@ def compile_templates():
     ]
 
 
+with_token = click.option(
+    "--token",
+    "-t",
+    help="The token for the fakts instance",
+    envvar="FAKTS_TOKEN",
+    required=True,
+)
+with_version = click.option(
+    "--version",
+    "-v",
+    help="Override the version of the app",
+    envvar="ARKITEKT_VERSION",
+)
+
+with_skip_cache = click.option(
+    "--nocache",
+    "-nc",
+    is_flag=True,
+    default=False,
+    help="Should we skip the cache",
+    envvar="ARKITEKT_NO_CACHE",
+)
+
+with_instance_id = click.option(
+    "--instance",
+    "-i",
+    default="main",
+    help="The token for the fakts instance",
+    envvar="REKUEST_INSTANCE",
+)
+
+headless = click.option(
+    "--headless",
+    "-h",
+    is_flag=True,
+    default=False,
+    help="Should we start headless",
+    envvar="ARKITEKT_HEADLESS",
+)
+
+
 @click.group()
 @click.pass_context
 def cli(ctx):
@@ -117,17 +158,16 @@ def run():
 
 @run.command()
 @click.option(
-    "--url", help="The fakts url for connection", default="http://localhost:8000"
-)
-@click.option(
-    "--public_url",
-    help="The fakts public_url for connection",
+    "--url",
+    help="The fakts url for connection",
     default="http://localhost:8000",
+    envvar="FAKTS_URL",
 )
-@click.option(
-    "--instance_id", "-i", help="The fakts instance_id for connection", default="main"
-)
-def easy(url, public_url, instance_id):
+@with_instance_id
+@headless
+@with_version
+@with_skip_cache
+def easy(url, instance, version=None, headless=False, nocache=False):
     """Runs the arkitekt app using the easy builder, which is the default builder
 
     \n
@@ -145,20 +185,26 @@ def easy(url, public_url, instance_id):
 
     asyncio.run(
         run_easy(
-            manifest.entrypoint,
-            manifest.identifier,
-            manifest.version,
-            url,
-            public_url,
-            instance_id,
+            manifest=manifest,
+            url=url,
+            instance_id=instance,
+            headless=headless,
+            nocache=nocache,
         )
     )
 
 
 @run.command()
-@click.option("--url", help="The fakts url for connection")
-@click.option("--token", help="The fakts token for connection")
-def port(url, token):
+@click.option(
+    "--url",
+    help="The fakts url for connection",
+    envvar="FAKTS_URL",
+    default="http://lok:8000",
+)
+@with_token
+@with_instance_id
+@with_skip_cache
+def port(url, token, instance, nocache=False):
     """Runs the arkitekt app"""
 
     from arkitekt.cli.run import run_port
@@ -170,7 +216,13 @@ def port(url, token):
         )
 
     asyncio.run(
-        run_port(manifest.entrypoint, manifest.identifier, manifest.version, url, token)
+        run_port(
+            manifest,
+            url=url,
+            token=token,
+            instance_id=instance,
+            nocache=nocache,
+        )
     )
 
 
@@ -181,7 +233,12 @@ def port(url, token):
     type=str,
     default="arkitekt.builders.easy",
 )
-def custom(builder):
+@with_token
+@with_instance_id
+@headless
+@with_version
+@with_skip_cache
+def custom(builder, token, instance, version=None, headless=False, nocache=False):
     """Runs the arkitekt app using a custom builder (import string)"""
 
     from arkitekt.cli.run import run_costum
@@ -194,12 +251,24 @@ def custom(builder):
 
     asyncio.run(
         run_costum(
-            manifest.entrypoint, manifest.identifier, manifest.version, builder=builder
+            manifest.entrypoint,
+            manifest.identifier,
+            version or manifest.version,
+            builder=builder,
+            nocache=nocache,
+            headless=headless,
         )
     )
 
 
 @cli.command()
+@click.option(
+    "--url",
+    help="The fakts url for connection",
+    default="http://localhost:8000",
+    envvar="FAKTS_URL",
+)
+@with_instance_id
 @click.option(
     "--builder",
     help="The builder used to construct the app",
@@ -211,7 +280,10 @@ def custom(builder):
     help="Should we check the whole directory for changes and reload them for dependencie",
     is_flag=True,
 )
-def dev(builder, deep):
+@headless
+@with_version
+@with_skip_cache
+def dev(url, instance, builder, deep, version=None, headless=False, nocache=False):
     """Runs the arkitekt app in dev mode (with hot reloading)"""
 
     from arkitekt.cli.dev import dev_module
@@ -224,11 +296,14 @@ def dev(builder, deep):
 
     asyncio.run(
         dev_module(
-            manifest.identifier,
-            manifest.version,
-            manifest.entrypoint,
+            manifest=manifest,
+            version=version,
             builder=builder,
             deep=deep,
+            url=url,
+            instance_id=instance,
+            headless=headless,
+            nocache=nocache,
         )
     )
 
@@ -408,6 +483,11 @@ def publish(build, tag):
     build = builds[build]
 
     manifest = build.manifest
+    if build.manifest.version == "dev":
+        raise click.ClickException(
+            "You cannot deploy a dev version. Please run `arkitekt version` first to set a version"
+        )
+
     check_if_manifest_already_deployed(manifest)
     docker_info = subprocess.check_output(["docker", "info"]).decode("utf-8")
     username = search_username_in_docker_info(docker_info)
@@ -443,6 +523,7 @@ def publish(build, tag):
         manifest,
         tag,
         command,
+        with_definitions=False,
     )
 
 
@@ -467,6 +548,7 @@ def build(dockerfile):
             "Dockerfile does not exists. Do you want to start the Dockerfile wizard?"
         ):
             docker_file_wizard(manifest)
+            click.confirm("Do you want to continue building?", abort=True)
 
     md = Panel(
         "Building for Port", subtitle="This may take a while...", subtitle_align="right"
@@ -484,6 +566,70 @@ def build(dockerfile):
     generate_build("port", build_id, manifest)
 
 
+@cli.command()
+def version():
+    """Updates the version of the arkitekt app"""
+
+    manifest = load_manifest()
+    if not manifest:
+        raise click.ClickException(
+            "No manifest found. Please run `arkitekt init` first before versioning an arkitekt app."
+        )
+
+    click.echo(f"Current Version: {manifest.version}")
+    new_version = click.prompt("New Version", default=manifest.version, type=str)
+
+    manifest.version = new_version
+    write_manifest(manifest)
+    click.echo("Manifest Updated")
+
+
+@cli.command()
+@click.option("--build", help="The build to use", type=str, default="latest")
+@with_version
+def stage(build, version=None):
+    """Stages the latest Build for testing"""
+    from arkitekt.cli.build import get_builds
+    import uuid
+
+    manifest = load_manifest()
+    if not manifest:
+        raise click.ClickException(
+            "No manifest found. Please run `arkitekt init` first before versioning an arkitekt app."
+        )
+
+    builds = get_builds()
+    assert (
+        build in builds
+    ), f"Build {build} not found. Please run `arkitekt build` first"
+    build = builds[build]
+    build_id = build.build_id
+
+    version = version or f"stage-{build_id}"
+
+    click.echo(f"Running inside docker: {manifest.identifier}:{version}")
+    docker_run = subprocess.run(
+        [
+            "docker",
+            "run",
+            "-it",
+            "--net",
+            "host",
+            "--gpus",
+            "all",
+            build_id,
+            "arkitekt",
+            "run",
+            "easy",
+            "--version",
+            version,
+            "--headless",
+        ],
+    )
+
+    raise click.ClickException("Not implemented yet")
+
+
 def prompt_scopes():
     used_scopes = []
     scopes = compile_scopes()
