@@ -22,7 +22,9 @@ class Manifest(BaseModel):
     identifier: str
     version: str
     author: str
+    logo: Optional[str]
     entrypoint: str
+    command: Optional[str]
     scopes: List[str]
     requirements: List[Requirement] = Field(default_factory=list)
     created_at: datetime.datetime = Field(default_factory=datetime.datetime.now)
